@@ -223,7 +223,7 @@ class QcVariableConfig(dict):
         self.update(config)
 
     def _validate_fx(self, input_fx, test_name):
-        """Thows exception if input_fx contains tokens not specifically allowed"""
+        """Throws exception if input_fx contains tokens not specifically allowed"""
         tokens = input_fx.split(' ')
         for token in tokens:
             try:
@@ -504,6 +504,8 @@ class QcConfigCreator:
         # - reshape masked y to (ntimes, ...) where ntimes is y.shape[0]
         # - assume that NaNs are same shape through time (i.e. will not work with wetting-drying)
         y_no_nans = y[~np.isnan(y)].reshape(y.shape[0], -1)
+        if y_no_nans.size == 0:
+            raise ValueError("CubicSpline require y to the finite.")
         spline = CubicSpline(x, y_no_nans, bc_type='periodic')
 
         # Get days of year for independent variable
